==> mgb-0.6.3.tar.bz2: install/mysql.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ================ //
	// mysql.php - 0.2  //
	// ================ //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// make sure nobody has direct access to this script
	if (!defined('INSTALL'))
		{
		echo "Start installation with <a href=\"install.php\">install.php</a>";
		die();
		}

	$db_hostname = $_SESSION['db_hostname'];
	$db_dbname = $_SESSION['db_dbname'];
	$db_username = $_SESSION['db_username'];
	$db_password = $_SESSION['db_password'];
	$db_prefix = $_SESSION['db_prefix'];

	$admin_name = $_SESSION['admin_name'];
	$admin_username = $_SESSION['admin_username'];
	$admin_password = md5($_SESSION['admin_password']);
	$admin_email = $_SESSION['admin_email'];
	$admin_gbemail = $_SESSION['admin_gbemail'];

	$gb_path = $_SERVER["SCRIPT_NAME"];
	$gb_path = str_replace("install/install.php", "", $gb_path);

	$h_domain = $_SERVER["HTTP_HOST"];

	// ++++++++++++++++++++++++++++++++++ //

	require ("../language/".$_SESSION['install_language']."/lang_admin.php");

	$sql = array();

	$sql[1] = "CREATE TABLE ".$db_prefix."captcha (
		  `code` VARCHAR( 11 ) NOT NULL,
		  PRIMARY KEY ( `code` )
		  ) TYPE = MYISAM ;";

	$sql[2] = "INSERT INTO ".$db_prefix."captcha ( `code` ) VALUES ( 'A B C D E F' );";

	$sql[3] = "CREATE TABLE ".$db_prefix."entries (
		  `ID` INT( 10 ) NOT NULL AUTO_INCREMENT PRIMARY KEY ,
		  `name` VARCHAR( 255 ) NOT NULL ,
		  `city` VARCHAR( 255 ) NOT NULL ,
		  `email` VARCHAR( 255 ) NOT NULL ,
		  `icq` VARCHAR( 255 ) NOT NULL ,
		  `aim` VARCHAR( 255 ) NOT NULL ,
		  `msn` VARCHAR( 255 ) NOT NULL ,
		  `hp` VARCHAR( 255 ) NOT NULL ,
		  `message` MEDIUMTEXT NOT NULL ,
		  `comment` MEDIUMTEXT NOT NULL ,
		  `ip` VARCHAR( 15 ) NOT NULL ,
		  `timestamp` VARCHAR( 255 ) NOT NULL ,
		  `user_notification` TINYINT( 1 ) NOT NULL ,
		  `user_show_email` TINYINT( 1 ) NOT NULL ,
		  `checked` TINYINT( 1 ) NOT NULL
		  ) TYPE = MYISAM ;";


	$sql[4] = "CREATE TABLE ".$db_prefix."lastip (
		  `lastIP` VARCHAR( 15 ) NOT NULL ,
		  PRIMARY KEY ( `lastIP` )
		  ) TYPE = MYISAM ;";


	$sql[5] = "CREATE TABLE ".$db_prefix."settings (
		  `title` VARCHAR(255) NOT NULL DEFAULT 'MGB 0.6',
		  `h_author` VARCHAR(255) NOT NULL, 
		  `h_domain` VARCHAR(255) NOT NULL, 
		  `gb_path` VARCHAR(255) NOT NULL, 
		  `h_keywords` VARCHAR(255) NOT NULL, 
		  `h_description` VARCHAR(255) NOT NULL, 
		  `admin_name` VARCHAR(255) NOT NULL, 
		  `admin_email` VARCHAR(255) NOT NULL, 
		  `admin_gbemail` VARCHAR(255) NOT NULL, 
		  `sendmail_admin` TINYINT(1) NOT NULL, 
		  `sendmail_admin_text` MEDIUMTEXT NOT NULL, 
		  `sendmail_user` TINYINT(1) NOT NULL, 
		  `sendmail_user_text` MEDIUMTEXT NOT NULL, 
		  `sendmail_user_notification_text` MEDIUMTEXT NOT NULL, 
		  `sendmail_comment_text` MEDIUMTEXT NOT NULL, 
		  `sendmail_contactmail_text` MEDIUMTEXT NOT NULL, 
		  `template_path` VARCHAR(255) NOT NULL DEFAULT 'mgbModern',
		  `template_style_path` VARCHAR(255) NOT NULL DEFAULT 'blue',
		  `iconset_path` VARCHAR(255) NOT NULL DEFAULT 'default', 
		  `language_path` VARCHAR(255) NOT NULL DEFAULT 'lang_german_latin9', 
		  `badwords` MEDIUMTEXT NOT NULL, 
		  `bbcode` TINYINT(1) NOT NULL DEFAULT '1', 
		  `smileys` TINYINT(1) NOT NULL DEFAULT '1', 
		  `captcha` TINYINT(1) NOT NULL DEFAULT '1', 
		  `user_notification` TINYINT(1) NOT NULL DEFAULT '1', 
		  `user_show_email` TINYINT(1) NOT NULL DEFAULT '1', 
		  `session_timeout` INT(4) NOT NULL DEFAULT '1800', 
		  `moderated` TINYINT(1) NOT NULL DEFAULT '1', 
		  `entries_per_page` TINYINT(2) NOT NULL DEFAULT '10',
		  `entries_order` TINYINT(1) NOT NULL DEFAULT '0', 
		  `spam_protection` TINYINT(1) NOT NULL DEFAULT '1', 
		  `ipblocker` TINYINT(1) NOT NULL DEFAULT '0', 
		  `wordwrap` TINYINT(2) NOT NULL DEFAULT '60',
		  `dateform` VARCHAR(5) NOT NULL DEFAULT 'd/m/Y', 
		  `gravatar_show` TINYINT(1) NOT NULL DEFAULT '0',
		  `gravatar_rating` TINYINT(1) NOT NULL DEFAULT '0', 
		  `version` VARCHAR(20) NOT NULL DEFAULT '0.6',
		  PRIMARY KEY (`title`) 
		 ) TYPE = MYISAM ;";

	$sql[6] = "INSERT INTO ".$db_prefix."settings (
		  `title` ,
		  `h_author` , 
		  `h_domain` , 
		  `gb_path` , 
		  `h_keywords` , 
		  `h_description` , 
		  `admin_name` , 
		  `admin_email` ,
		  `admin_gbemail` ,
		  `sendmail_admin` , 
		  `sendmail_admin_text` , 
		  `sendmail_user` , 
		  `sendmail_user_text` , 
		  `sendmail_user_notification_text` , 
		  `sendmail_comment_text` , 
		  `sendmail_contactmail_text` , 
		  `template_path` ,
		  `template_style_path` ,
		  `iconset_path` , 
		  `language_path` , 
		  `badwords` , 
		  `bbcode` , 
		  `smileys` , 
		  `captcha` , 
		  `user_notification` , 
		  `user_show_email` , 
		  `session_timeout` , 
		  `moderated` , 
		  `entries_per_page` ,
		  `entries_order` , 
		  `spam_protection` , 
		  `ipblocker` , 
		  `wordwrap` ,
		  `dateform` ,
		  `gravatar_show` ,
		  `gravatar_rating` , 
		  `version`
		  ) VALUES (
		  'MGB ".MGB_VERSION."', 
		  '', 
		  '".$h_domain."', 
		  '".$gb_path."', 
		  '', 
		  '', 
		  '".$admin_name."', 
		  '".$admin_email."',
		  '".$admin_gbemail."',
		  '1',
		  '".$lang['sendmail_admin_text']."',
		  '1',
		  '".$lang['sendmail_user_text']."',
		  '".$lang['sendmail_user_notification_text']."',
		  '".$lang['sendmail_comment_text']."',
		  '".$lang['sendmail_contactmail_text']."',
		  'mgbModern',
		  'blue',
		  'default', 
		  '".$_SESSION['install_language']."', 
		  '', 
		  '1', 
		  '1', 
		  '1', 
		  '1', 
		  '1',
		  '1800', 
		  '1', 
		  '10',
		  '0',
		  '1', 
		  '0', 
		  '60',
		  'd/m/Y',
		  '0',
		  '0', 
		  '".MGB_VERSION."'
		  );";


	$sql[7] = "CREATE TABLE ".$db_prefix."user (
		  `ID` INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
		  `user_name` VARCHAR( 255 ) NOT NULL ,
		  `user_password` VARCHAR( 255 ) NOT NULL ,
		  `user_key` VARCHAR( 16 ) NOT NULL ,
		  `user_email` VARCHAR( 255 ) NOT NULL ,
		  `user_is_active` TINYINT( 1 ) NOT NULL ,
		  `user_level` TINYINT( 1 ) NOT NULL ,
		  `r_settings` TINYINT( 1 ) NOT NULL ,
		  `r_activate` TINYINT( 1 ) NOT NULL ,
		  `r_deactivate` TINYINT( 1 ) NOT NULL ,
		  `r_delete` TINYINT( 1 ) NOT NULL ,
		  `r_edit` TINYINT( 1 ) NOT NULL ,
		  `logged_in` INT( 255 ) NOT NULL ,
		  `logged_out` TINYINT( 1 ) NOT NULL ,
		  `np_key` VARCHAR( 16 ) NOT NULL ,
		  `np_expiration` VARCHAR( 255 ) NOT NULL
		  ) TYPE = MYISAM ;";

	$sql[8] = "INSERT INTO ".$db_prefix."user ( 
		  `ID` ,
		  `user_name` ,
		  `user_password` ,
		  `user_key` ,
		  `user_email` ,
		  `user_is_active` ,
		  `user_level` ,
		  `r_settings` ,
		  `r_activate` ,
		  `r_deactivate` ,
		  `r_delete` ,
		  `r_edit`,
		  `logged_in` ,
		  `logged_out`,
		  `np_key` ,
		  `np_expiration` 
		  ) VALUES (
		  NULL,
		  '".$admin_username."',
		  '".$admin_password."',
		  '0',
		  '".$admin_email."',
		  '1',
		  '0',
		  '1',
		  '1',
		  '1',
		  '1',
		  '1',
		  '".time()."',
		  '1',
		  '',
		  ''
		  );";

	if(!isset($success)) { $success = 0; }
	
	for($i = 1; $i <= 8; $i++)
		{
		$sqlcommand = $sql[$i];
		$link = @mysql_connect($db_hostname, $db_username, $db_password) or die ("(install.php) Error: ".mysql_error());
		@mysql_select_db($db_dbname, $link) or die ("(install.php) Error: ".mysql_error());
		if(@mysql_query($sqlcommand, $link) == TRUE)
			{
			$success++;
			}
		}
?>

==> mgb-0.6.4.tar.bz2: install/mysql.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ================ //
	// mysql.php - 0.2  //
	// ================ //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// make sure nobody has direct access to this script
	if (!defined('INSTALL'))
		{
		echo "Error! Start installation with <a href=\"install.php\">install.php</a>";
		die();
		}

	$db_hostname = $_SESSION['db_hostname'];
	$db_dbname = $_SESSION['db_dbname'];
	$db_username = $_SESSION['db_username'];
	$db_password = $_SESSION['db_password'];
	$db_prefix = $_SESSION['db_prefix'];

	$admin_name = $_SESSION['admin_name'];
	$admin_username = $_SESSION['admin_username'];
	$admin_password = md5($_SESSION['admin_password']);
	$admin_email = $_SESSION['admin_email'];
	$admin_gbemail = $_SESSION['admin_gbemail'];

	$gb_path = $_SERVER["SCRIPT_NAME"];
	$gb_path = str_replace("install/install.php", "", $gb_path);

	$h_domain = $_SERVER["HTTP_HOST"];

	// ++++++++++++++++++++++++++++++++++ //

	require ("../language/".$_SESSION['install_language']."/lang_admin.php");

	$sql = array();

	$sql[1] = "CREATE TABLE ".$db_prefix."captcha (
		  `code` VARCHAR( 11 ) NOT NULL,
		  PRIMARY KEY ( `code` )
		  ) TYPE = MYISAM ;";

	$sql[2] = "INSERT INTO ".$db_prefix."captcha ( `code` ) VALUES ( 'A B C D E F' );";

	$sql[3] = "CREATE TABLE ".$db_prefix."entries (
		  `ID` INT( 10 ) NOT NULL AUTO_INCREMENT PRIMARY KEY ,
		  `name` VARCHAR( 255 ) NOT NULL ,
		  `city` VARCHAR( 255 ) NOT NULL ,
		  `email` VARCHAR( 255 ) NOT NULL ,
		  `icq` VARCHAR( 255 ) NOT NULL ,
		  `aim` VARCHAR( 255 ) NOT NULL ,
		  `msn` VARCHAR( 255 ) NOT NULL ,
		  `hp` VARCHAR( 255 ) NOT NULL ,
		  `message` MEDIUMTEXT NOT NULL ,
		  `comment` MEDIUMTEXT NOT NULL ,
		  `ip` VARCHAR( 15 ) NOT NULL ,
		  `timestamp` VARCHAR( 255 ) NOT NULL ,
		  `user_notification` TINYINT( 1 ) NOT NULL ,
		  `user_show_email` TINYINT( 1 ) NOT NULL ,
		  `checked` TINYINT( 1 ) NOT NULL
		  ) TYPE = MYISAM ;";


	$sql[4] = "CREATE TABLE ".$db_prefix."lastip (
		  `lastIP` VARCHAR( 15 ) NOT NULL ,
		  PRIMARY KEY ( `lastIP` )
		  ) TYPE = MYISAM ;";


	$sql[5] = "CREATE TABLE ".$db_prefix."settings (
		  `title` VARCHAR(255) NOT NULL DEFAULT 'MGB 0.6',
		  `h_author` VARCHAR(255) NOT NULL, 
		  `h_domain` VARCHAR(255) NOT NULL, 
		  `gb_path` VARCHAR(255) NOT NULL, 
		  `h_keywords` VARCHAR(255) NOT NULL, 
		  `h_description` VARCHAR(255) NOT NULL, 
		  `admin_name` VARCHAR(255) NOT NULL, 
		  `admin_email` VARCHAR(255) NOT NULL, 
		  `admin_gbemail` VARCHAR(255) NOT NULL, 
		  `sendmail_admin` TINYINT(1) NOT NULL, 
		  `sendmail_admin_text` MEDIUMTEXT NOT NULL, 
		  `sendmail_user` TINYINT(1) NOT NULL, 
		  `sendmail_user_text` MEDIUMTEXT NOT NULL, 
		  `sendmail_user_notification_text` MEDIUMTEXT NOT NULL, 
		  `sendmail_comment_text` MEDIUMTEXT NOT NULL, 
		  `sendmail_contactmail_text` MEDIUMTEXT NOT NULL, 
		  `template_path` VARCHAR(255) NOT NULL DEFAULT 'mgbModern',
		  `template_style_path` VARCHAR(255) NOT NULL DEFAULT 'blue',
		  `iconset_path` VARCHAR(255) NOT NULL DEFAULT 'default', 
		  `language_path` VARCHAR(255) NOT NULL DEFAULT 'lang_german_latin9', 
		  `badwords` MEDIUMTEXT NOT NULL, 
		  `bbcode` TINYINT(1) NOT NULL DEFAULT '1', 
		  `smileys` TINYINT(1) NOT NULL DEFAULT '1', 
		  `captcha` TINYINT(1) NOT NULL DEFAULT '1', 
		  `user_notification` TINYINT(1) NOT NULL DEFAULT '1', 
		  `user_show_email` TINYINT(1) NOT NULL DEFAULT '1', 
		  `session_timeout` INT(4) NOT NULL DEFAULT '1800', 
		  `moderated` TINYINT(1) NOT NULL DEFAULT '1', 
		  `entries_per_page` TINYINT(2) NOT NULL DEFAULT '10',
		  `entries_order` TINYINT(1) NOT NULL DEFAULT '0', 
		  `spam_protection` TINYINT(1) NOT NULL DEFAULT '1', 
		  `ipblocker` TINYINT(1) NOT NULL DEFAULT '0', 
		  `wordwrap` TINYINT(2) NOT NULL DEFAULT '60',
		  `dateform` VARCHAR(5) NOT NULL DEFAULT 'd/m/Y', 
		  `gravatar_show` TINYINT(1) NOT NULL DEFAULT '0',
		  `gravatar_rating` TINYINT(1) NOT NULL DEFAULT '0', 
		  `version` VARCHAR(20) NOT NULL DEFAULT '0.6',
		  PRIMARY KEY (`title`) 
		 ) TYPE = MYISAM ;";

	$sql[6] = "INSERT INTO ".$db_prefix."settings (
		  `title` ,
		  `h_author` , 
		  `h_domain` , 
		  `gb_path` , 
		  `h_keywords` , 
		  `h_description` , 
		  `admin_name` , 
		  `admin_email` ,
		  `admin_gbemail` ,
		  `sendmail_admin` , 
		  `sendmail_admin_text` , 
		  `sendmail_user` , 
		  `sendmail_user_text` , 
		  `sendmail_user_notification_text` , 
		  `sendmail_comment_text` , 
		  `sendmail_contactmail_text` , 
		  `template_path` ,
		  `template_style_path` ,
		  `iconset_path` , 
		  `language_path` , 
		  `badwords` , 
		  `bbcode` , 
		  `smileys` , 
		  `captcha` , 
		  `user_notification` , 
		  `user_show_email` , 
		  `session_timeout` , 
		  `moderated` , 
		  `entries_per_page` ,
		  `entries_order` , 
		  `spam_protection` , 
		  `ipblocker` , 
		  `wordwrap` ,
		  `dateform` ,
		  `gravatar_show` ,
		  `gravatar_rating` , 
		  `version`
		  ) VALUES (
		  'MGB ".MGB_VERSION."', 
		  '', 
		  '".$h_domain."', 
		  '".$gb_path."', 
		  '', 
		  '', 
		  '".$admin_name."', 
		  '".$admin_email."',
		  '".$admin_gbemail."',
		  '1',
		  '".$lang['sendmail_admin_text']."',
		  '1',
		  '".$lang['sendmail_user_text']."',
		  '".$lang['sendmail_user_notification_text']."',
		  '".$lang['sendmail_comment_text']."',
		  '".$lang['sendmail_contactmail_text']."',
		  'mgbModern',
		  'blue',
		  'default', 
		  '".$_SESSION['install_language']."', 
		  '', 
		  '1', 
		  '1', 
		  '1', 
		  '1', 
		  '1',
		  '1800', 
		  '1', 
		  '10',
		  '0',
		  '1', 
		  '0', 
		  '60',
		  'd/m/Y',
		  '0',
		  '0', 
		  '".MGB_VERSION."'
		  );";


	$sql[7] = "CREATE TABLE ".$db_prefix."user (
		  `ID` INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
		  `user_name` VARCHAR( 255 ) NOT NULL ,
		  `user_password` VARCHAR( 255 ) NOT NULL ,
		  `user_key` VARCHAR( 16 ) NOT NULL ,
		  `user_email` VARCHAR( 255 ) NOT NULL ,
		  `user_is_active` TINYINT( 1 ) NOT NULL ,
		  `user_level` TINYINT( 1 ) NOT NULL ,
		  `r_settings` TINYINT( 1 ) NOT NULL ,
		  `r_activate` TINYINT( 1 ) NOT NULL ,
		  `r_deactivate` TINYINT( 1 ) NOT NULL ,
		  `r_delete` TINYINT( 1 ) NOT NULL ,
		  `r_edit` TINYINT( 1 ) NOT NULL ,
		  `logged_in` INT( 255 ) NOT NULL ,
		  `logged_out` TINYINT( 1 ) NOT NULL ,
		  `np_key` VARCHAR( 16 ) NOT NULL ,
		  `np_expiration` VARCHAR( 255 ) NOT NULL
		  ) TYPE = MYISAM ;";

	$sql[8] = "INSERT INTO ".$db_prefix."user ( 
		  `ID` ,
		  `user_name` ,
		  `user_password` ,
		  `user_key` ,
		  `user_email` ,
		  `user_is_active` ,
		  `user_level` ,
		  `r_settings` ,
		  `r_activate` ,
		  `r_deactivate` ,
		  `r_delete` ,
		  `r_edit`,
		  `logged_in` ,
		  `logged_out`,
		  `np_key` ,
		  `np_expiration` 
		  ) VALUES (
		  NULL,
		  '".$admin_username."',
		  '".$admin_password."',
		  '0',
		  '".$admin_email."',
		  '1',
		  '0',
		  '1',
		  '1',
		  '1',
		  '1',
		  '1',
		  '".time()."',
		  '1',
		  '',
		  ''
		  );";

	if(!isset($success)) { $success = 0; }
	
	for($i = 1; $i <= 8; $i++)
		{
		$sqlcommand = $sql[$i];
		$link = @mysql_connect($db_hostname, $db_username, $db_password) or die ("(mysql.php) Error: ".mysql_error());
		@mysql_select_db($db_dbname, $link) or die ("(mysql.php) Error: ".mysql_error());
		if(@mysql_query($sqlcommand, $link) == TRUE)
			{
			$success++;
			}
		}
?>
